@@ -11,13 +11,14 @@ gettext.install('ows', '/usr/share/locale', unicode=1)
 
 
 name = "ows"
-long_name =  _('OSD Workspace Switcher')
-version = "0.071011"
+long_name =  _('GNOME OSD Workspace Switcher')
+version = "0.20100530"
 image_dir = "/usr/share/pixmaps"
 localedir = "/usr/share/locale"
 
-copyright = 'Copyright © 2007 David Villa Alises'
-authors = ["David Villa Alises <David.Villa@uclm.es>"]
+copyright = "Copyright © 2010 David Villa Alises"
+author = "David Villa Alises"
+author_email = "<David.Villa@uclm.es>"
 
 website = 'http://arco.inf-cr.uclm.es/~david.villa/ows.html'
 
